import { Logo } from "@/components/ui/logo"
import Link from "next/link"
import { ArrowLeft } from "lucide-react"

export default function PrivacyPolicy() {
  return (
    <div className="dark min-h-screen bg-[#0f1116] text-gray-200">
      <header className="border-b border-gray-800">
        <div className="container mx-auto py-6 flex items-center justify-between">
          <div className="flex items-center gap-4">
            <Link href="/" className="flex items-center text-gray-400 hover:text-white transition-colors">
              <ArrowLeft className="mr-2 h-5 w-5" />
              <span>Back to Home</span>
            </Link>
          </div>
          <Link href="/">
            <Logo />
          </Link>
        </div>
      </header>

      <main className="container mx-auto py-12 px-4">
        <h1 className="text-4xl font-bold mb-8">Privacy Policy</h1>

        <div className="prose prose-invert max-w-none">
          <p className="text-lg mb-6">Last Updated: March 9, 2025</p>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">1. Introduction</h2>
            <p>
              Welcome to LeadzMachine. We respect your privacy and are committed to protecting your personal data. This
              privacy policy will inform you about how we look after your personal data when you visit our website and
              use our services, and tell you about your privacy rights and how the law protects you.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">2. Data We Collect</h2>
            <p>
              We collect several different types of information for various purposes to provide and improve our service
              to you:
            </p>
            <ul className="list-disc pl-6 mt-4 space-y-2">
              <li>
                <strong>Personal Data:</strong> While using our Service, we may ask you to provide us with certain
                personally identifiable information that can be used to contact or identify you. This may include, but
                is not limited to:
                <ul className="list-disc pl-6 mt-2 space-y-1">
                  <li>Email address</li>
                  <li>First name and last name</li>
                  <li>Payment information</li>
                  <li>LinkedIn profile information</li>
                </ul>
              </li>
              <li>
                <strong>Usage Data:</strong> We may also collect information on how the Service is accessed and used.
                This may include information such as your computer's Internet Protocol address, browser type, browser
                version, the pages of our Service that you visit, the time and date of your visit, the time spent on
                those pages, unique device identifiers, and other diagnostic data.
              </li>
              <li>
                <strong>LinkedIn Data:</strong> When you use our extension to extract data from LinkedIn, we process the
                information you choose to extract. This data is processed on your behalf and according to your
                instructions.
              </li>
            </ul>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">3. How We Use Your Data</h2>
            <p>LeadzMachine uses the collected data for various purposes:</p>
            <ul className="list-disc pl-6 mt-4 space-y-2">
              <li>To provide and maintain our Service</li>
              <li>To notify you about changes to our Service</li>
              <li>To allow you to participate in interactive features of our Service when you choose to do so</li>
              <li>To provide customer support</li>
              <li>To gather analysis or valuable information so that we can improve our Service</li>
              <li>To monitor the usage of our Service</li>
              <li>To detect, prevent and address technical issues</li>
              <li>To process payments and prevent fraudulent transactions</li>
            </ul>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">4. Data Storage and Security</h2>
            <p>
              The security of your data is important to us. We strive to use commercially acceptable means to protect
              your Personal Data. However, no method of transmission over the Internet or method of electronic storage
              is 100% secure. While we strive to use commercially acceptable means to protect your Personal Data, we
              cannot guarantee its absolute security.
            </p>
            <p className="mt-4">
              We retain your Personal Data only for as long as is necessary for the purposes set out in this Privacy
              Policy. We will retain and use your Personal Data to the extent necessary to comply with our legal
              obligations, resolve disputes, and enforce our legal agreements and policies.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">5. Your Data Protection Rights</h2>
            <p>Depending on your location, you may have certain rights regarding your personal data:</p>
            <ul className="list-disc pl-6 mt-4 space-y-2">
              <li>The right to access, update or delete the information we have on you</li>
              <li>
                The right of rectification - the right to have your information corrected if it is inaccurate or
                incomplete
              </li>
              <li>The right to object to our processing of your Personal Data</li>
              <li>
                The right of restriction - the right to request that we restrict the processing of your personal
                information
              </li>
              <li>
                The right to data portability - the right to be provided with a copy of your Personal Data in a
                structured, machine-readable and commonly used format
              </li>
              <li>
                The right to withdraw consent at any time where we relied on your consent to process your personal
                information
              </li>
            </ul>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">6. Third-Party Services</h2>
            <p>
              Our Service may contain links to other sites that are not operated by us. If you click on a third-party
              link, you will be directed to that third party's site. We strongly advise you to review the Privacy Policy
              of every site you visit.
            </p>
            <p className="mt-4">
              We have no control over and assume no responsibility for the content, privacy policies or practices of any
              third-party sites or services.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">7. LinkedIn Terms Compliance</h2>
            <p>
              When using our Service to extract data from LinkedIn, you agree to comply with LinkedIn's User Agreement
              and Privacy Policy. You acknowledge that you are responsible for ensuring your use of the extracted data
              complies with LinkedIn's terms and applicable laws.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">8. Changes to This Privacy Policy</h2>
            <p>
              We may update our Privacy Policy from time to time. We will notify you of any changes by posting the new
              Privacy Policy on this page and updating the "Last Updated" date at the top of this Privacy Policy.
            </p>
            <p className="mt-4">
              You are advised to review this Privacy Policy periodically for any changes. Changes to this Privacy Policy
              are effective when they are posted on this page.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">9. Contact Us</h2>
            <p>If you have any questions about this Privacy Policy, please contact us:</p>
            <ul className="list-disc pl-6 mt-4">
              <li>By email: support@leadzmachine.com</li>
            </ul>
          </section>
        </div>
      </main>

      <footer className="bg-[#0a0b0f] py-8 border-t border-gray-800">
        <div className="container mx-auto px-4 text-center text-gray-500">
          <p>© {new Date().getFullYear()} LeadzMachine. All rights reserved.</p>
        </div>
      </footer>
    </div>
  )
}

