import { Logo } from "@/components/ui/logo"
import Link from "next/link"
import { ArrowLeft } from "lucide-react"

export default function TermsAndConditions() {
  return (
    <div className="dark min-h-screen bg-[#0f1116] text-gray-200">
      <header className="border-b border-gray-800">
        <div className="container mx-auto py-6 flex items-center justify-between">
          <div className="flex items-center gap-4">
            <Link href="/" className="flex items-center text-gray-400 hover:text-white transition-colors">
              <ArrowLeft className="mr-2 h-5 w-5" />
              <span>Back to Home</span>
            </Link>
          </div>
          <Link href="/">
            <Logo />
          </Link>
        </div>
      </header>

      <main className="container mx-auto py-12 px-4">
        <h1 className="text-4xl font-bold mb-8">Terms and Conditions</h1>

        <div className="prose prose-invert max-w-none">
          <p className="text-lg mb-6">Last Updated: March 9, 2025</p>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">1. Introduction</h2>
            <p>
              Welcome to LeadzMachine. These Terms and Conditions govern your use of our website and Chrome extension
              (collectively, the "Service"). By using the Service, you agree to these Terms. If you disagree with any
              part of the terms, you may not access the Service.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">2. Accounts</h2>
            <p>
              When you create an account with us, you must provide information that is accurate, complete, and current
              at all times. Failure to do so constitutes a breach of the Terms, which may result in immediate
              termination of your account on our Service.
            </p>
            <p className="mt-4">
              You are responsible for safeguarding the password that you use to access the Service and for any
              activities or actions under your password. You agree not to disclose your password to any third party. You
              must notify us immediately upon becoming aware of any breach of security or unauthorized use of your
              account.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">3. Subscription Terms</h2>
            <p>
              Some parts of the Service are billed on a subscription basis. You will be billed in advance on a recurring
              basis, depending on the type of subscription plan you select.
            </p>
            <p className="mt-4">
              At the end of each billing period, your subscription will automatically renew under the same conditions
              unless you cancel it or LeadzMachine cancels it. You may cancel your subscription at any time through your
              account settings.
            </p>
            <p className="mt-4">
              A valid payment method, including credit card, is required to process the payment for your subscription.
              By submitting such payment information, you automatically authorize LeadzMachine to charge all
              subscription fees incurred through your account to any such payment instruments.
            </p>
            <p className="mt-4">
              All subscriptions are non-refundable except as required by law or as explicitly stated in these Terms.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">4. Use of the Service</h2>
            <p>
              Our Service allows you to extract and export LinkedIn profile data. You agree to use this Service only for
              legitimate business purposes and in compliance with all applicable laws and regulations, including data
              protection laws.
            </p>
            <p className="mt-4">You agree not to use the Service:</p>
            <ul className="list-disc pl-6 mt-4 space-y-2">
              <li>In any way that violates any applicable national or international law or regulation</li>
              <li>
                In any way that infringes upon the rights of others, or in any way is illegal, threatening, fraudulent,
                or harmful
              </li>
              <li>To engage in any activity that constitutes spam or excessive scraping</li>
              <li>
                To attempt to interfere with, compromise the system integrity or security, or decipher any transmissions
                to or from the servers running the Service
              </li>
              <li>To collect or track the personal information of others</li>
              <li>To circumvent, disable, or otherwise interfere with security-related features of the Service</li>
              <li>
                To impersonate or attempt to impersonate LeadzMachine, a LeadzMachine employee, another user, or any
                other person or entity
              </li>
            </ul>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">5. LinkedIn Terms Compliance</h2>
            <p>
              When using our Service to extract data from LinkedIn, you agree to comply with LinkedIn's User Agreement
              and Privacy Policy. You acknowledge that you are responsible for ensuring your use of the extracted data
              complies with LinkedIn's terms and applicable laws.
            </p>
            <p className="mt-4">
              LeadzMachine is not affiliated with, endorsed by, or sponsored by LinkedIn. We provide a tool that
              interacts with LinkedIn's platform, but we are an independent service.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">6. Intellectual Property</h2>
            <p>
              The Service and its original content, features, and functionality are and will remain the exclusive
              property of LeadzMachine and its licensors. The Service is protected by copyright, trademark, and other
              laws of both the country and foreign countries. Our trademarks and trade dress may not be used in
              connection with any product or service without the prior written consent of LeadzMachine.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">7. Limitation of Liability</h2>
            <p>
              In no event shall LeadzMachine, nor its directors, employees, partners, agents, suppliers, or affiliates,
              be liable for any indirect, incidental, special, consequential or punitive damages, including without
              limitation, loss of profits, data, use, goodwill, or other intangible losses, resulting from:
            </p>
            <ul className="list-disc pl-6 mt-4 space-y-2">
              <li>Your access to or use of or inability to access or use the Service</li>
              <li>Any conduct or content of any third party on the Service</li>
              <li>Any content obtained from the Service</li>
              <li>Unauthorized access, use or alteration of your transmissions or content</li>
            </ul>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">8. Disclaimer</h2>
            <p>
              Your use of the Service is at your sole risk. The Service is provided on an "AS IS" and "AS AVAILABLE"
              basis. The Service is provided without warranties of any kind, whether express or implied, including, but
              not limited to, implied warranties of merchantability, fitness for a particular purpose, non-infringement
              or course of performance.
            </p>
            <p className="mt-4">
              LeadzMachine does not warrant that a) the Service will function uninterrupted, secure or available at any
              particular time or location; b) any errors or defects will be corrected; c) the Service is free of viruses
              or other harmful components; or d) the results of using the Service will meet your requirements.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">9. Governing Law</h2>
            <p>
              These Terms shall be governed and construed in accordance with the laws of India, without regard to its
              conflict of law provisions.
            </p>
            <p className="mt-4">
              Our failure to enforce any right or provision of these Terms will not be considered a waiver of those
              rights. If any provision of these Terms is held to be invalid or unenforceable by a court, the remaining
              provisions of these Terms will remain in effect.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">10. Changes to Terms</h2>
            <p>
              We reserve the right, at our sole discretion, to modify or replace these Terms at any time. If a revision
              is material we will try to provide at least 30 days' notice prior to any new terms taking effect. What
              constitutes a material change will be determined at our sole discretion.
            </p>
            <p className="mt-4">
              By continuing to access or use our Service after those revisions become effective, you agree to be bound
              by the revised terms. If you do not agree to the new terms, please stop using the Service.
            </p>
          </section>

          <section className="mb-10">
            <h2 className="text-2xl font-semibold mb-4">11. Contact Us</h2>
            <p>If you have any questions about these Terms, please contact us:</p>
            <ul className="list-disc pl-6 mt-4">
              <li>By email: support@leadzmachine.com</li>
            </ul>
          </section>
        </div>
      </main>

      <footer className="bg-[#0a0b0f] py-8 border-t border-gray-800">
        <div className="container mx-auto px-4 text-center text-gray-500">
          <p>© {new Date().getFullYear()} LeadzMachine. All rights reserved.</p>
        </div>
      </footer>
    </div>
  )
}

