import { StepCard } from "./step-card"
import { Search, UserCheck, FileSpreadsheet, ArrowRight } from "lucide-react"

export function HowItWorksSection() {
  return (
    <section className="py-20 bg-[#161921]">
      <div className="container mx-auto">
        <h2 className="text-4xl font-bold mb-16 text-center">How it works?</h2>

        <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
          {/* Step 1 */}
          <StepCard
            stepNumber={1}
            badgeText="Search"
            title="Search: Finding the Right Profiles"
            icon={<Search size={48} className="text-[#d4ff00]" />}
          >
            <div className="space-y-4">
              <p className="text-gray-300">
                Enter your target keywords like job titles, skills, or industries to find relevant LinkedIn profiles.
              </p>

              <ul className="space-y-2 text-gray-300">
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Use specific keywords for better results</span>
                </li>
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Filter by location, company, or experience</span>
                </li>
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Save your common searches for later use</span>
                </li>
              </ul>
            </div>
          </StepCard>

          {/* Step 2 */}
          <StepCard
            stepNumber={2}
            badgeText="Prospect"
            title="Identify Prospect: Select Your Targets"
            icon={<UserCheck size={48} className="text-[#d4ff00]" />}
          >
            <div className="space-y-4">
              <p className="text-gray-300">
                Review the search results and select the profiles that match your criteria for lead generation.
              </p>

              <ul className="space-y-2 text-gray-300">
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>View profile details without leaving the extension</span>
                </li>
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>One-click selection of multiple profiles</span>
                </li>
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Automatic email discovery for selected profiles</span>
                </li>
              </ul>
            </div>
          </StepCard>

          {/* Step 3 */}
          <StepCard
            stepNumber={3}
            badgeText="Excel"
            title="Download Data: Export to Excel"
            icon={<FileSpreadsheet size={48} className="text-[#d4ff00]" />}
          >
            <div className="space-y-4">
              <p className="text-gray-300">
                Export all selected profiles with their contact details directly to Excel or CSV format.
              </p>

              <ul className="space-y-2 text-gray-300">
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Choose between CSV or XLSX formats</span>
                </li>
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Customize which fields to include in export</span>
                </li>
                <li className="flex items-start gap-2">
                  <ArrowRight className="h-5 w-5 mt-0.5 text-[#d4ff00] shrink-0" />
                  <span>Access your export history anytime</span>
                </li>
              </ul>
            </div>
          </StepCard>
        </div>
      </div>
    </section>
  )
}

