import { Badge } from "@/components/ui/badge"
import type { ReactNode } from "react"

interface StepCardProps {
  stepNumber: number
  badgeText: string
  title: string
  icon: ReactNode
  children: ReactNode
}

export function StepCard({ stepNumber, badgeText, title, icon, children }: StepCardProps) {
  return (
    <div className="bg-[#1c1f2a] rounded-xl p-8 relative group hover:bg-[#232736] transition-colors duration-300 h-full">
      <div className="flex justify-between items-center mb-6">
        <h3 className="text-2xl font-bold">Step {stepNumber}</h3>
        <Badge className="bg-[#d4ff00] text-black hover:bg-[#c2eb00]">{badgeText}</Badge>
      </div>

      <div className="flex flex-col items-center mb-6">
        <div className="p-4 bg-[#0f1116] rounded-full mb-4 transform group-hover:scale-110 transition-transform duration-300">
          {icon}
        </div>
        <h4 className="text-xl font-semibold text-center">{title}</h4>
      </div>

      <div className="mt-6">{children}</div>
    </div>
  )
}

