"use client"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Logo } from "@/components/ui/logo"
import { Menu, X } from "lucide-react"

export function Navigation() {
  const [isMenuOpen, setIsMenuOpen] = useState(false)

  const toggleMenu = () => {
    setIsMenuOpen(!isMenuOpen)
  }

  return (
    <nav className="container mx-auto py-8">
      <div className="flex items-center justify-between">
        <Logo className="scale-110" />

        {/* Mobile menu button */}
        <button
          className="lg:hidden text-gray-300 hover:text-white p-2"
          onClick={toggleMenu}
          aria-label={isMenuOpen ? "Close menu" : "Open menu"}
        >
          {isMenuOpen ? <X size={28} /> : <Menu size={28} />}
        </button>

        {/* Desktop navigation */}
        <div className="hidden lg:flex items-center gap-5">
          <Button
            variant="outline"
            size="lg"
            className="text-blue-400 border-blue-400 hover:bg-blue-400/10 text-base px-6"
          >
            Login
          </Button>
          <Button size="lg" className="bg-blue-600 hover:bg-blue-700 text-base px-6">
            Sign Up
          </Button>
        </div>
      </div>

      {/* Mobile navigation */}
      {isMenuOpen && (
        <div className="lg:hidden mt-5 py-5 bg-[#1c1f2a] rounded-lg shadow-lg">
          <div className="flex flex-col space-y-4 px-5">
            <div className="flex flex-col sm:flex-row gap-4 pt-2">
              <Button
                variant="outline"
                size="lg"
                className="text-blue-400 border-blue-400 hover:bg-blue-400/10 w-full sm:w-auto text-base"
              >
                Login
              </Button>
              <Button size="lg" className="bg-blue-600 hover:bg-blue-700 w-full sm:w-auto text-base">
                Sign Up
              </Button>
            </div>
          </div>
        </div>
      )}
    </nav>
  )
}

