import { Button } from "@/components/ui/button"
import { Card, CardContent } from "@/components/ui/card"
import { Plus } from "lucide-react"

interface PricingFeature {
  text: string
}

// Update the PricingCardProps interface to include a buttonUrl prop
interface PricingCardProps {
  title: string
  planName: string
  price?: string
  description: string
  features: PricingFeature[]
  buttonText: string
  buttonUrl?: string // Add this new prop
}

// Update the function parameters to include buttonUrl
export function PricingCard({
  title,
  planName,
  price,
  description,
  features,
  buttonText,
  buttonUrl,
}: PricingCardProps) {
  return (
    <Card className="bg-[#1c1f2a] border-0 overflow-hidden h-full flex flex-col">
      <CardContent className="p-8 flex flex-col flex-grow">
        <div className="flex flex-col items-start gap-2 mb-2">
          <div className="bg-black inline-block px-3 py-1.5 rounded-full text-sm">
            <span className="font-medium">{title}</span>
          </div>

          <div className="bg-[#d4ff00] text-black px-4 py-2 rounded-full w-full text-center">
            <span className="font-bold">{planName}</span>
          </div>
        </div>

        {price && <div className="text-2xl font-bold text-center mb-6">{price}</div>}

        <p className="text-gray-300 mb-8">{description}</p>

        <ul className="space-y-4 mb-8 flex-grow">
          {features.map((feature, index) => (
            <li key={index} className="flex items-start gap-2">
              <Plus className="h-5 w-5 mt-0.5 text-[#d4ff00]" />
              <span>{feature.text}</span>
            </li>
          ))}
        </ul>

        {/* Update the Button to include an anchor tag if buttonUrl is provided */}
        {buttonUrl ? (
          <a href={buttonUrl} target="_blank" rel="noopener noreferrer" className="w-full">
            <Button className="w-full bg-[#d4ff00] hover:bg-[#c2eb00] text-black font-bold py-6 mt-auto">
              {buttonText}
            </Button>
          </a>
        ) : (
          <Button className="w-full bg-[#d4ff00] hover:bg-[#c2eb00] text-black font-bold py-6 mt-auto">
            {buttonText}
          </Button>
        )}
      </CardContent>
    </Card>
  )
}

