"use client"

import { useEffect, useRef } from "react"
import { TestimonialCard } from "./testimonial-card"

export function TestimonialsSection() {
  const testimonials = [
    {
      name: "John Doe",
      role: "Software Engineer",
      image:
        "https://images.unsplash.com/photo-1599566150163-29194dcaad36?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=3387&q=80",
      testimonial:
        "LeadzMachine has completely transformed how I connect with potential clients. The ability to export LinkedIn profiles directly to Excel has saved me countless hours of manual work. The interface is intuitive and the results are impressive!",
    },
    {
      name: "Robert Johnson",
      role: "Product Manager",
      image:
        "https://images.unsplash.com/photo-1535713875002-d1d0cf377fde?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxzZWFyY2h8Mnx8YXZhdGFyfGVufDB8fDB8fHww&auto=format&fit=crop&w=800&q=60",
      testimonial:
        "As a product manager, finding the right connections is crucial. LeadzMachine has helped me identify key stakeholders and decision-makers in my target companies. The data export feature is seamless and the insights are invaluable.",
    },
    {
      name: "Jane Smith",
      role: "Data Scientist",
      image:
        "https://images.unsplash.com/photo-1580489944761-15a19d654956?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxzZWFyY2h8NXx8YXZhdGFyfGVufDB8fDB8fHww&auto=format&fit=crop&w=800&q=60",
      testimonial:
        "I've been using this LinkedIn extension for a few weeks and I'm already seeing the benefits. It's helped me discover and connect with professionals in my field that I would have missed otherwise. Plus, it's incredibly user-friendly!",
    },
    {
      name: "Emily Davis",
      role: "UX Designer",
      image:
        "https://images.unsplash.com/photo-1438761681033-6461ffad8d80?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxzZWFyY2h8MTB8fGF2YXRhcnxlbnwwfHwwfHx8MA%3D%3D&auto=format&fit=crop&w=800&q=60",
      testimonial:
        "Networking has always been a challenge for me, but with LeadzMachine, it's become a breeze. The connections it suggests are remarkably relevant, saving me hours of searching and scrolling. It's like having a networking genie!",
    },
    {
      name: "Tyler Durden",
      role: "Soap Developer",
      image:
        "https://images.unsplash.com/photo-1472099645785-5658abf4ff4e?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=3540&q=80",
      testimonial:
        "I found LeadzMachine while looking for ways to expand my professional network. It's been an absolute lifesaver! Finding potential clients has never been easier. I've seen a significant boost in inquiries since I started using this tool!",
    },
    {
      name: "Dora",
      role: "The Explorer",
      image:
        "https://images.unsplash.com/photo-1544725176-7c40e5a71c5e?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=3534&q=80",
      testimonial:
        "Best value for money! LeadzMachine has helped me discover new territories in my professional landscape. The data quality is excellent and the export features make it easy to integrate with my existing workflow. Highly recommended!",
    },
  ]

  const scrollRef = useRef<HTMLDivElement>(null)

  // Auto-scroll effect
  useEffect(() => {
    const scrollContainer = scrollRef.current
    if (!scrollContainer) return

    // Clone the first few items and append them to the end for infinite scroll effect
    const scrollContent = scrollContainer.querySelector(".scroll-content")
    if (!scrollContent) return

    const scrollAnimation = () => {
      if (!scrollContainer) return

      if (scrollContainer.scrollLeft >= scrollContent.scrollWidth / 2) {
        scrollContainer.scrollLeft = 0
      } else {
        scrollContainer.scrollLeft += 1
      }
    }

    const animationInterval = setInterval(scrollAnimation, 30)

    // Pause animation on hover
    scrollContainer.addEventListener("mouseenter", () => {
      clearInterval(animationInterval)
    })

    scrollContainer.addEventListener("mouseleave", () => {
      clearInterval(animationInterval)
    })

    return () => {
      clearInterval(animationInterval)
    }
  }, [])

  return (
    <section className="py-20 overflow-hidden">
      <div className="container mx-auto">
        <h2 className="text-4xl font-bold mb-16 text-center">Testimonials</h2>

        {/* Scrolling Testimonial Cards */}
        <div
          ref={scrollRef}
          className="overflow-x-auto scrollbar-hide pb-6"
          style={{
            scrollbarWidth: "none",
            msOverflowStyle: "none",
          }}
        >
          <div className="scroll-content inline-flex gap-6 min-w-max">
            {/* First set of testimonials */}
            {testimonials.map((testimonial, index) => (
              <div key={`first-${index}`} className="w-[300px] md:w-[350px]">
                <TestimonialCard
                  name={testimonial.name}
                  role={testimonial.role}
                  image={testimonial.image}
                  testimonial={testimonial.testimonial}
                />
              </div>
            ))}

            {/* Duplicate set for seamless scrolling */}
            {testimonials.map((testimonial, index) => (
              <div key={`second-${index}`} className="w-[300px] md:w-[350px]">
                <TestimonialCard
                  name={testimonial.name}
                  role={testimonial.role}
                  image={testimonial.image}
                  testimonial={testimonial.testimonial}
                />
              </div>
            ))}
          </div>
        </div>

        <style jsx>{`
          .scrollbar-hide::-webkit-scrollbar {
            display: none;
          }
        `}</style>
      </div>
    </section>
  )
}

